namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    
    [Serialized]
    [Weight(100)]                                          
    public partial class ExoticTrailMixItem :
        FoodItem            
    {
        public override string FriendlyName                     { get { return "Exotic Trail Mix"; } }
        public override string Description                      { get { return "Seed snack from the desert, tundra and wetlands."; } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 4, Fat = 3, Protein = 1, Vitamins = 4};
        public override float Calories                          { get { return 250; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(SeedProductionSkill), 3)]    
    public partial class ExoticTrailMixRecipe : Recipe
    {
        public ExoticTrailMixRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ExoticTrailMixItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<FireweedSeedItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<CriminiMushroomSporesItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<PricklyPearSeedItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(ExoticTrailMixRecipe), Item.Get<ExoticTrailMixItem>().UILink(), 0.5f, typeof(SeedProductionSpeedSkill)); 
            this.Initialize("Exotic Trail Mix", typeof(ExoticTrailMixRecipe));
            CraftingComponent.AddRecipe(typeof(FarmersTableObject), this);
        }
    }
}