namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    
    [Serialized]
    [Weight(100)]                                          
    public partial class ForestTrailMixItem :
        FoodItem            
    {
        public override string FriendlyName                     { get { return "Forest Trail Mix"; } }
        public override string Description                      { get { return "Seed snack from the forest."; } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 4, Fat = 2, Protein = 1, Vitamins = 5};
        public override float Calories                          { get { return 250; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(SeedProductionSkill), 2)]    
    public partial class ForestTrailMixRecipe : Recipe
    {
        public ForestTrailMixRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ForestTrailMixItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<FernSporeItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<HuckleberrySeedItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<TomatoSeedItem>(typeof(SeedProductionEfficiencySkill), 10, SeedProductionEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(ForestTrailMixRecipe), Item.Get<ForestTrailMixItem>().UILink(), 0.5f, typeof(SeedProductionSpeedSkill)); 
            this.Initialize("Forest Trail Mix", typeof(ForestTrailMixRecipe));
            CraftingComponent.AddRecipe(typeof(FarmersTableObject), this);
        }
    }
}